        function getT(rr,cc){
       if(rr==1 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260815 a 00</strong> UTC HH+132 (rango:120-144)<br><strong>control +<br>EPS</strong>';}
       if(rr==1 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260815 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>1</strong> representante: <strong>9</strong> miembros: 22 <br>1,2,4,5,6,7,9,11,15,18,20,25,28,31,32,33,35,38,39,41,44,49';}
       if(rr==1 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260815 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>2</strong> representante: <strong>13</strong> miembros: 20 <strong>control</strong><br>0,3,8,10,12,13,16,17,19,24,27,36,37,40,42,45,46,47,48,50';}
       if(rr==1 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260815 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>3</strong> representante: <strong>43</strong> miembros: 9 <br>14,21,22,23,26,29,30,34,43';}
       if(rr==8 && cc==0){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260815 a 00</strong> UTC HH+132 (rango:120-144)<br><strong>control +<br>EPS</strong>';}
       if(rr==8 && cc==1){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260815 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>1</strong> representante: <strong>9</strong> miembros: 22 <br>1,2,4,5,6,7,9,11,15,18,20,25,28,31,32,33,35,38,39,41,44,49';}
       if(rr==8 && cc==2){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260815 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>2</strong> representante: <strong>13</strong> miembros: 20 <strong>control</strong><br>0,3,8,10,12,13,16,17,19,24,27,36,37,40,42,45,46,47,48,50';}
       if(rr==8 && cc==3){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260815 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>3</strong> representante: <strong>43</strong> miembros: 9 <br>14,21,22,23,26,29,30,34,43';}
       if(rr==18 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260815 a 00</strong> UTC HH+132 (rango:120-144)<br><strong>control +<br>EPS</strong>';}
       if(rr==18 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260815 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>1</strong> representante: <strong>9</strong> miembros: 22 <br>1,2,4,5,6,7,9,11,15,18,20,25,28,31,32,33,35,38,39,41,44,49';}
       if(rr==18 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260815 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>2</strong> representante: <strong>13</strong> miembros: 20 <strong>control</strong><br>0,3,8,10,12,13,16,17,19,24,27,36,37,40,42,45,46,47,48,50';}
       if(rr==18 && cc==3){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260815 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>3</strong> representante: <strong>43</strong> miembros: 9 <br>14,21,22,23,26,29,30,34,43';}
       if(rr==24 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260815 a 00</strong> UTC HH+132 (rango:120-144)<br><strong>control +<br>EPS</strong>';}
       if(rr==24 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260815 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>1</strong> representante: <strong>9</strong> miembros: 22 <br>1,2,4,5,6,7,9,11,15,18,20,25,28,31,32,33,35,38,39,41,44,49';}
       if(rr==24 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260815 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>2</strong> representante: <strong>13</strong> miembros: 20 <strong>control</strong><br>0,3,8,10,12,13,16,17,19,24,27,36,37,40,42,45,46,47,48,50';}
       if(rr==24 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260815 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>3</strong> representante: <strong>43</strong> miembros: 9 <br>14,21,22,23,26,29,30,34,43';}
       if(rr==44 && cc==0){return '<strong>Desviacion estandar e isohipsas de altura geopotencial (m) en 500 hPa</strong><br><br><strong>20260815 a 00</strong> UTC HH+132 (rango:120-144)<br><strong>control +<br>EPS</strong>';}
       if(rr==44 && cc==1){return '<strong>Desviacion estandar e isohipsas de altura geopotencial (m) en 500 hPa</strong><br><br><strong>20260815 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>1</strong> representante: <strong>9</strong> miembros: 22 <br>1,2,4,5,6,7,9,11,15,18,20,25,28,31,32,33,35,38,39,41,44,49';}
       if(rr==44 && cc==2){return '<strong>Desviacion estandar e isohipsas de altura geopotencial (m) en 500 hPa</strong><br><br><strong>20260815 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>2</strong> representante: <strong>13</strong> miembros: 20 <strong>control</strong><br>0,3,8,10,12,13,16,17,19,24,27,36,37,40,42,45,46,47,48,50';}
       if(rr==44 && cc==3){return '<strong>Desviacion estandar e isohipsas de altura geopotencial (m) en 500 hPa</strong><br><br><strong>20260815 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>3</strong> representante: <strong>43</strong> miembros: 9 <br>14,21,22,23,26,29,30,34,43';}
       if(rr==45 && cc==0){return '<strong>Spaguetti de presion en superficie (hPa)</strong><br><br><strong>20260815 a 00</strong> UTC HH+132 (rango:120-144)<br><strong>control +<br>EPS</strong>';}
       if(rr==45 && cc==1){return '<strong>Spaguetti de presion en superficie (hPa)</strong><br><br><strong>20260815 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>1</strong> representante: <strong>9</strong> miembros: 22 <br>1,2,4,5,6,7,9,11,15,18,20,25,28,31,32,33,35,38,39,41,44,49';}
       if(rr==45 && cc==2){return '<strong>Spaguetti de presion en superficie (hPa)</strong><br><br><strong>20260815 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>2</strong> representante: <strong>13</strong> miembros: 20 <strong>control</strong><br>0,3,8,10,12,13,16,17,19,24,27,36,37,40,42,45,46,47,48,50';}
       if(rr==45 && cc==3){return '<strong>Spaguetti de presion en superficie (hPa)</strong><br><br><strong>20260815 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>3</strong> representante: <strong>43</strong> miembros: 9 <br>14,21,22,23,26,29,30,34,43';}
}
